summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rwxr-xr-xtools/ci-build.sh10
1 files changed, 6 insertions, 4 deletions
diff --git a/tools/ci-build.sh b/tools/ci-build.sh
index c5915fac..0e72b2d9 100755
--- a/tools/ci-build.sh
+++ b/tools/ci-build.sh
@@ -127,7 +127,7 @@ init_wine() {
: "${ci_test_fatal:=yes}"
# ci_variant:
# One of debug, reduced, legacy, production
: "${ci_variant:=production}"
# ci_runtime:
@@ -376,9 +376,11 @@ case "$ci_buildsys" in
${make} install DESTDIR=$(pwd)/DESTDIR
( cd DESTDIR && find . -ls )
- ${make} -C doc dbus-docs.tar.xz
- tar -C $(pwd)/DESTDIR -xf doc/dbus-docs.tar.xz
- ( cd DESTDIR/dbus-docs && find . -ls )
+ if [ "$ci_variant" != "production-no-upload-docs" ]; then
+ ${make} -C doc dbus-docs.tar.xz
+ tar -C $(pwd)/DESTDIR -xf doc/dbus-docs.tar.xz
+ ( cd DESTDIR/dbus-docs && find . -ls )
+ fi
if [ "$ci_sudo" = yes ] && [ "$ci_test" = yes ]; then
sudo ${make} install
@@ -127,7 +127,7 @@ init_wine() {
: "${ci_test_fatal:=yes}"
# ci_variant:
-# One of debug, reduced, legacy, production
+# One of debug, reduced, legacy, production, production-no-upload-docs
: "${ci_variant:=production}"
# ci_runtime: